@@ -1,7 +1,7 @@
 package Paws::Kinesis::MemoryCaller;
 use 5.008001;
 
-our $VERSION = "0.05";
+our $VERSION = "0.06";
 
 =head1 NAME
 
@@ -15,7 +15,7 @@ Paws::Kinesis::MemoryCaller - A Paws Caller with in-memory Kinesis.
     my $kinesis = Paws->service('Kinesis',
         region      => 'N/A',
         caller      => Paws::Kinesis::MemoryCaller->new(),
-        credentials => Paws::Credential::None->new(),
+        credentials => Paws::Credential::Environment->new(),
     );
 
     # Create a Kinesis stream...
